Request

Struct Request 

pub struct Request<M> { /* private fields */ }
JSON-RPC Request object

Implementations

Source

impl<'a, M> Request<M>
where M: Serialize + Deserialize<'a>,

pub fn new0(method: M) -> Request<M>

Create a new Request object with the given method with no ID (no response expected)

pub fn new(id: Id, method: M) -> Request<M>

Create a new Request object with the given method and ID

pub fn into_parts(self) -> (Option<Id>, M)

Split the Request object into its parts (useful for 3rd party serialization)

pub fn from_parts(id: Option<Id>, method: M) -> Request<M>

Combine the parts into a Request object (useful for 3rd party de-serialization)