pub struct Request<M> { /* private fields */ }Expand description
JSON-RPC Request object
Implementations
Sourceimpl<'a, M> Request<M>where
M: Serialize + Deserialize<'a>,
impl<'a, M> Request<M>where
M: Serialize + Deserialize<'a>,
Sourcepub fn new0(method: M) -> Request<M>
pub fn new0(method: M) -> Request<M>
Create a new Request object with the given method with no ID (no response expected)
Sourcepub fn new(id: Id, method: M) -> Request<M>
pub fn new(id: Id, method: M) -> Request<M>
Create a new Request object with the given method and ID
Sourcepub fn into_parts(self) -> (Option<Id>, M)
pub fn into_parts(self) -> (Option<Id>, M)
Split the Request object into its parts (useful for 3rd party serialization)
Sourcepub fn from_parts(id: Option<Id>, method: M) -> Request<M>
pub fn from_parts(id: Option<Id>, method: M) -> Request<M>
Combine the parts into a Request object (useful for 3rd party de-serialization)